==> fisoco-0.6-2016-01-30.tar.gz: fisoco-0.6/include/cli.h <==
/*
 * Fisoco, a FInding SOrting and COnverting free software
 * Copyright 2015 Félicien PILLOT <felicien.pillot@member.fsf.org>
 *
 * This file is part of Fisoco.
 *
 * Fisoco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Fisoco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Fisoco.  If not, see <http://www.gnu.org/licenses/>.
 *
 *//////////////////////////////////////
/****************
 *    cli.h     *
 *    ~~~~~~    *
 ****************/

#ifndef FISOCO_CLI_H
#define FISOCO_CLI_H

#if HAVE_CONFIG_H
#  include <config.h>
#endif /* HAVE_CONFIG_H */
#if HAVE_UNISTD_H
#  include <unistd.h>
#endif /* HAVE_UNISTD_H */
#include <iostream>
#include "search.h"
// i18n
#include "../include/gettext.h"

class Cli
{
public:
    Cli ();
    
    // Called from the worker thread.
    void notify (std::list<std::string> founded_files);
    void error_dialog (std::string message);
    
private:
    
    int check_args (std::string command);
    void display_version ();
    void erase ();
    void help ();
    void help (std::string argument);
    std::string prompt ();
    void read ();
    void search (std::string arg);
    int start_search (Glib::ustring search);
    
    Search cli_Worker;
    Glib::Threads::Thread* cli_WorkerThread;
    std::list<std::string> Rfiles;
};

#endif // FISOCO_CLI_H

==> fisoco-0.7-2016-02-23.tar.gz: fisoco-0.7/include/cli.h <==
/*
 * Fisoco, a FInding SOrting and COnverting free software
 * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
 *
 * This file is part of Fisoco.
 *
 * Fisoco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Fisoco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Fisoco.  If not, see <http://www.gnu.org/licenses/>.
 *
 *//////////////////////////////////////
/****************
 *    cli.h     *
 *    ~~~~~~    *
 ****************/

#ifndef FISOCO_CLI_H
#define FISOCO_CLI_H

#if HAVE_CONFIG_H
#  include <config.h>
#endif /* HAVE_CONFIG_H */
#if HAVE_UNISTD_H
#  include <unistd.h>
#endif /* HAVE_UNISTD_H */
#include <iostream>
#include "search.h"
#include "list.h"
// i18n
#include "gettext.h"

class Cli
{
public:
    Cli ();
    
    // Called from the worker thread.
    void notify (std::list<std::string> files, std::string dir);
    
private:
    
    void backup ();
    void backup (std::string filename);
    int check_args (std::string command);
    void clean ();
    void display_version ();
    void help ();
    void help (std::string argument);
    void load ();
    void load (std::string filename);
    void info (int numbers);
    std::string prompt ();
    void read ();
    void search (std::string arg);
    int start_search (Glib::ustring search);

    Search cli_Worker;
    Glib::Threads::Thread* cli_WorkerThread;

    List results;
};

#endif // FISOCO_CLI_H
